@@ -46,8 +46,8 @@ void DataHandler::setCurrentArticle(QString articleName)
 
 void DataHandler::saveArticleToFile(QMap<QString, QStringList> content)
 {
-    article = new QFile(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/AudioWiki/"+ currentArticleTitle.toLower().normalized(QString::NormalizationForm_D)+".txt");
-    articleLinks = new QFile(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/AudioWiki/"+ currentArticleTitle.toLower().normalized(QString::NormalizationForm_D)+".dat");
+    article = new QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ currentArticleTitle.toLower().normalized(QString::NormalizationForm_D)+".txt");
+    articleLinks = new QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ currentArticleTitle.toLower().normalized(QString::NormalizationForm_D)+".dat");
     if (!article->open(QIODevice::WriteOnly))
         qDebug()<<"file error";
     else
@@ -72,7 +72,7 @@ QString DataHandler::getArticleFromFile()
 {
 
     QString line;
-    QFile file(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/AudioWiki/"+ currentArticleTitle.toLower().normalized(QString::NormalizationForm_D)+".txt");
+    QFile file(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ currentArticleTitle.toLower().normalized(QString::NormalizationForm_D)+".txt");
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
         return "";
 
@@ -105,11 +105,11 @@ void DataHandler::removeFiles()
     {
         if (!savedFiles->contains(allLoadedFiles->at(i)))
         {
-            QFile textFile(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/AudioWiki/"+ allLoadedFiles->at(i).toLower().normalized(QString::NormalizationForm_D)+".txt");
+            QFile textFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ allLoadedFiles->at(i).toLower().normalized(QString::NormalizationForm_D)+".txt");
             textFile.remove();
-            QFile datFile(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/AudioWiki/"+ allLoadedFiles->at(i).toLower().normalized(QString::NormalizationForm_D)+".dat");
+            QFile datFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ allLoadedFiles->at(i).toLower().normalized(QString::NormalizationForm_D)+".dat");
             datFile.remove();
-            QFile soundFile(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/AudioWiki/"+ allLoadedFiles->at(i).toLower().normalized(QString::NormalizationForm_D)+".wav");
+            QFile soundFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ allLoadedFiles->at(i).toLower().normalized(QString::NormalizationForm_D)+".wav");
             soundFile.remove();
         }
     }
